=======
History
=======

0.4.0 (2017-10-08)
------------------

* Test on PyPI.. Non working version.

0.2 (2017-10-07)
------------------

* Checkpoint of the last version working with 2.x. This checkpoint contains code from many years ago.
